<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "Merma".
 *
 * @property string $id
 * @property string|null $idObra
 * @property string|null $idUnidadMedida
 * @property string|null $idPartida
 * @property string|null $idUsuario
 * @property string|null $producto
 * @property string|null $descripcion
 * @property string|null $cantidad
 * @property float|null $precio
 * @property string|null $creado
 * @property string|null $modificado
 * @property string|null $eliminado
 *
 * @property Obra $idObra0
 * @property Partida $idPartida0
 * @property UnidadMedida $idUnidadMedida0
 * @property Usuario $idUsuario0
 */
class Merma extends ModeloBase
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'Merma';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id'], 'required'],
            [['descripcion'], 'string'],
            [['precio'], 'number'],
            [['creado', 'modificado', 'eliminado'], 'safe'],
            [['id', 'idObra', 'idUnidadMedida', 'idPartida', 'idUsuario'], 'string', 'max' => 36],
            [['producto', 'cantidad'], 'string', 'max' => 255],
            [['id'], 'unique'],
            [['idObra'], 'exist', 'skipOnError' => true, 'targetClass' => Obra::class, 'targetAttribute' => ['idObra' => 'id']],
            [['idPartida'], 'exist', 'skipOnError' => true, 'targetClass' => Partida::class, 'targetAttribute' => ['idPartida' => 'id']],
            [['idUnidadMedida'], 'exist', 'skipOnError' => true, 'targetClass' => UnidadMedida::class, 'targetAttribute' => ['idUnidadMedida' => 'id']],
            [['idUsuario'], 'exist', 'skipOnError' => true, 'targetClass' => Usuario::class, 'targetAttribute' => ['idUsuario' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'idObra' => 'Id Obra',
            'idUnidadMedida' => 'Id Unidad Medida',
            'idPartida' => 'Id Partida',
            'idUsuario' => 'Id Usuario',
            'producto' => 'Producto',
            'descripcion' => 'Descripcion',
            'cantidad' => 'Cantidad',
            'precio' => 'Precio',
            'creado' => 'Creado',
            'modificado' => 'Modificado',
            'eliminado' => 'Eliminado',
        ];
    }

    public function getObra()
    {
        return $this->hasOne(Obra::class, ['id' => 'idObra']);
    }

    public function getPartida()
    {
        return $this->hasOne(Partida::class, ['id' => 'idPartida']);
    }

    public function getUnidadMedida()
    {
        return $this->hasOne(UnidadMedida::class, ['id' => 'idUnidadMedida']);
    }

    public function getUsuario()
    {
        return $this->hasOne(Usuario::class, ['id' => 'idUsuario']);
    }
}
